unit WizardForms;
{***********************************************************************

  Copyright (C) 2004  Zaher Dirkey (zaher@parmaja.com)

  This file is part of Parmaja tools.

  PunTranslator is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published
  by the Free Software Foundation; either version 2 of the License,
  or (at your option) any later version.

  PunTranslator is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
  MA  02111-1307  USA

************************************************************************}

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  FileCtrl, MyParser, Registry, Dialogs, StdCtrls, ComCtrls;

type
  TWizardForm = class(TForm)
    PageControl: TPageControl;
    ChooseSheet: TTabSheet;
    FolderSheet: TTabSheet;
    NextBtn: TButton;
    CloseBtn: TButton;
    LoadLastChk: TRadioButton;
    LoadFilesChk: TRadioButton;
    UpgradeFilesChk: TRadioButton;
    Label1: TLabel;
    Label10: TLabel;
    LclLangFolderEdit: TEdit;
    Button1: TButton;
    OrgLangFolderEdit: TEdit;
    Button2: TButton;
    FinishBtn: TButton;
    Label3: TLabel;
    Label2: TLabel;
    Label4: TLabel;
    procedure CloseBtnClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure Button2Click(Sender: TObject);
    procedure Button1Click(Sender: TObject);
    procedure NextBtnClick(Sender: TObject);
    procedure FinishBtnClick(Sender: TObject);
    procedure PageControlChanging(Sender: TObject;
      var AllowChange: Boolean);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
  private
  public
    procedure UpdateButtons;
    procedure UpdateMainForm;
    procedure LoadLanguage;
    procedure LoadLastLanguage;
    procedure UpgradeLanguage;
  end;

implementation

uses Main;

{$R *.dfm}

procedure TWizardForm.CloseBtnClick(Sender: TObject);
begin
  ModalResult:=mrCancel;
end;

procedure TWizardForm.FormCreate(Sender: TObject);
var
  aReg: TRegistry;
begin
  aReg := TRegistry.Create;
  aReg.OpenKey('Software\Options\PunTranslator', True);
  OrgLangFolderEdit.Text := aReg.ReadString('OrginalLangPath');
  LclLangFolderEdit.Text := aReg.ReadString('LocalLangPath');
  aReg.Free;
  PageControl.ActivePageIndex:=0;
  UpdateButtons;
  FinishBtn.BoundsRect:=NextBtn.BoundsRect;
  ActiveControl:=LoadLastChk;
end;

procedure TWizardForm.LoadLastLanguage;
begin
  LoadLanguage;
end;

procedure TWizardForm.Button2Click(Sender: TObject);
var
  d: string;
begin
  d := OrgLangFolderEdit.Text;
  if SelectDirectory('Select your lang folder', '', d) then
  begin
    OrgLangFolderEdit.Text := d;
  end;
end;

procedure TWizardForm.Button1Click(Sender: TObject);
var
  d: string;
begin
  d := LclLangFolderEdit.Text;
  if SelectDirectory('Select your lang folder', '', d) then
  begin
    LclLangFolderEdit.Text := d;
  end;
end;

procedure TWizardForm.NextBtnClick(Sender: TObject);
begin
  if LoadLastChk.Checked then
  begin
    if (OrgLangFolderEdit.Text = '') or (LclLangFolderEdit.Text='') then
      FolderSheet.Show
    else
      LoadLastLanguage;
  end
  else if LoadFilesChk.Checked then
    FolderSheet.Show
  else if UpgradeFilesChk.Checked then
    FolderSheet.Show;
  UpdateButtons;
end;

procedure TWizardForm.FinishBtnClick(Sender: TObject);
begin
  if (LoadLastChk.Checked) or (LoadFilesChk.Checked) then
    LoadLanguage
  else if UpgradeFilesChk.Checked then
    UpgradeLanguage;
end;

procedure TWizardForm.UpdateMainForm;
begin
  MainForm.OrgLangFolderEdit.Text := OrgLangFolderEdit.Text;
  MainForm.LclLangFolderEdit.Text := LclLangFolderEdit.Text;
end;

procedure TWizardForm.UpgradeLanguage;
var
  aFiles: TLangFiles;
  b1,b2:Boolean;
begin
  UpdateMainForm;
  aFiles:=nil;
  with MainForm do
  begin
    LoadFiles(aFiles, LclLangFolderEdit.Text);
    LoadFiles(Files, OrgLangFolderEdit.Text);
    LoadFiles(EnFiles, OrgLangFolderEdit.Text);

    LogEdit.Lines.BeginUpdate;
    LogEdit.Clear;
    LogEdit.Lines.Add('--------- deprecated words ---------');
    LogEdit.Lines.Add('');
    b1:=aFiles.Compare(EnFiles, LogEdit.Lines);
      PageControl.ActivePageIndex := 1;
    LogEdit.Lines.Add('');
    LogEdit.Lines.Add('--------- New words ---------');
    LogEdit.Lines.Add('');
    LogEdit.Lines.EndUpdate;
    b2:=Files.Import(aFiles, LogEdit.Lines);
    Files['lang_common']['lang_direction']:=aFiles['lang_common']['lang_direction'];
    Files['lang_common']['lang_encoding']:=aFiles['lang_common']['lang_encoding'];
    Enumerate;
    if not b1 or not b2 then
      PageControl.ActivePageIndex := 1;
    aFiles.Free;
  end;
  ModalResult:=mrOK;
end;

procedure TWizardForm.LoadLanguage;
var
  b1,b2:Boolean;
begin
  UpdateMainForm;
  with MainForm do
  begin
    LoadFiles(Files, LclLangFolderEdit.Text);
    LoadFiles(EnFiles, OrgLangFolderEdit.Text);
    LogEdit.Lines.BeginUpdate;
    LogEdit.Clear;
    LogEdit.Lines.Add('--------- deprecated words ---------');
    LogEdit.Lines.Add('');
    b1:=Files.Compare(EnFiles, LogEdit.Lines);
    LogEdit.Lines.Add('');
    LogEdit.Lines.Add('--------- New words ---------');
    LogEdit.Lines.Add('');
    LogEdit.Lines.EndUpdate;
    b2:=EnFiles.Compare(Files, LogEdit.Lines);
    Enumerate;
    if not b1 or not b2 then
      PageControl.ActivePageIndex := 1;
  end;
  ModalResult:=mrOK;
end;

procedure TWizardForm.PageControlChanging(Sender: TObject;
  var AllowChange: Boolean);
begin
  AllowChange:=False;
end;

procedure TWizardForm.UpdateButtons;
begin
  NextBtn.Visible:=PageControl.ActivePage=ChooseSheet;
  FinishBtn.Visible:=not NextBtn.Visible;
end;

procedure TWizardForm.FormClose(Sender: TObject; var Action: TCloseAction);
begin
  Action:=caHide;
end;

end.
